<template>
  <el-dialog
    width="70%"
    title="标签信息"
    top="3vh"
    :visible.sync="innerVisible"
    append-to-body
    @close="$emit('update:currshowlist', false)"
    :show="currshowlist"
    :close-on-click-modal="false"
    class="small-warehousing-label-dialog"
  >
    <el-form :model="dataForm" ref="dataForm" label-width="90px" class="l-mes">
      <el-row>
        <el-col :span="12">
          <el-form-item label="零件号" prop="partNo">
            <el-input v-model="dataForm.partNo" disabled></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="零件描述" prop="partName">
            <el-input v-model="dataForm.partName" disabled></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="SN号" prop="outBatchNo"
            ><el-input
              v-model="dataForm.outBatchNo"
              placeholder="SN号"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="IFS批次号" prop="ifsBatchNo"
            ><el-input
              v-model="dataForm.ifsBatchNo"
              placeholder="IFS批次号"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="生产数量" prop="productQty">
            <el-input
              v-model="dataForm.productQty"
              placeholder="生产数量"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="单位" prop="unit"
            ><el-input v-model="dataForm.unit" placeholder="单位"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="innerVisible = false">取消</el-button>
      <el-button type="primary" v-thinclick="`printData`">打印</el-button>
    </span>
  </el-dialog>
</template>
<script>
import { mapGetters } from 'vuex'
import { getObj } from '@/api/basic/part'
import getLodop from '@/util/lodop'
import { getYearAndMonth } from '@/util/date'
import { judgeLabelMark } from '@/api/warehouse/check'
export default {
  props: {
    currshowlist: {
      type: Boolean,
      default: false
    },
    printLabelInfo: {
      type: Object,
      default: () => {
        return {}
      }
    }
  },
  data() {
    return {
      innerVisible: false,
      dataForm: {},
      partInfo: null
    }
  },
  watch: {
    currshowlist() {
      this.innerVisible = this.currshowlist
      if (this.currshowlist) {
        this.$nextTick(() => {
          getObj(this.printLabelInfo.partId).then((response) => {
            const resData = response.data
            this.partInfo = resData.data
          })
          this.dataForm = {
            partNo: this.printLabelInfo.partNo,
            partName: this.printLabelInfo.partName,
            outBatchNo: this.printLabelInfo.outBatchNo,
            ifsBatchNo: this.printLabelInfo.ifsBatchNo,
            productQty: this.printLabelInfo.productQty,
            lotTrackingIfs: this.printLabelInfo.lotTrackingIfs,
            unit: this.printLabelInfo.unit
          }
          console.log('this.dataForm', this.dataForm)
        })
      }
    }
  },
  computed: {
    ...mapGetters(['userInfo'])
  },
  methods: {
    printData() {
      // 找出所有要打印的SN的list
      const snList = []
      snList.push(this.dataForm.outBatchNo)
      // 查询是否正在盘点
      judgeLabelMark(snList).then((resp) => {
        const respData = resp.data
        const markArr = respData.data
        let markFlag = true
        markFlag = markArr.includes(this.dataForm.outBatchNo)
        if (markFlag) {
          this.beginPrint(true)
        } else {
          this.beginPrint(false)
        }
      })
    },
    beginPrint(isCheck) {
      this.LODOP = getLodop()
      this.dataForm.lotTrackingIfs = this.partInfo.lotTrackingIfs
      console.log(this.dataForm)
      const qr = {
        part_no: this.dataForm.partNo,
        lot_batch_no: this.dataForm.ifsBatchNo,
        qty_arrived: this.dataForm.productQty,
        wdr: this.dataForm.outBatchNo,
        unit_meas: this.dataForm.unit,
        sn_no: this.dataForm.outBatchNo
      }
      const qrStr = JSON.stringify(qr)
      if (isCheck) {
        const currYearAndMonth = getYearAndMonth()
        this.LODOP.SET_LICENSES(
          '南通市鑫阳软件开发有限公司',
          '60F8E5078AE17DEB340C94BC7E83CAFF',
          '',
          ''
        )
        this.LODOP.PRINT_INITA(0, -1, 500, 300, '')
        this.LODOP.SET_PRINT_PAGESIZE(0, 1000, 600, '')
        this.LODOP.SET_PRINT_MODE('PRINT_NOCOLLATE', 1)
        this.LODOP.ADD_PRINT_TEXT(37, 45, 63, 20, '数量：')
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(
          63,
          46,
          134,
          20,
          this.dataForm.productQty + ' ' + this.dataForm.unit
        )
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(37, 92, 63, 20, 'SN号：')
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(69, 93, 134, 20, this.dataForm.outBatchNo)
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(23, 140, 77, 20, '零件号：')
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(57, 141, 182, 22, this.dataForm.partNo)
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_BARCODE(45, 215, 149, 181, 'QRCode', qrStr)
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'QRCodeVersion', 7)
        this.LODOP.SET_PRINT_STYLEA(0, 'QRCodeErrorLevel', 'L')
        this.LODOP.ADD_PRINT_LINE(215, 20, 215, 163, 0, 2)
        this.LODOP.ADD_PRINT_LINE(215, 197, 215, 360, 0, 2)
        this.LODOP.ADD_PRINT_TEXT(208, 163, 34, 15, currYearAndMonth)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.ADD_PRINT_LINE(225, 20, 225, 360, 0, 2)
        // this.LODOP.PREVIEW()
        this.LODOP.PRINT()
      } else {
        this.LODOP.SET_LICENSES(
          '南通市鑫阳软件开发有限公司',
          '60F8E5078AE17DEB340C94BC7E83CAFF',
          '',
          ''
        )
        this.LODOP.PRINT_INITA(0, -1, 500, 300, '')
        this.LODOP.SET_PRINT_PAGESIZE(0, 1000, 600, '')
        this.LODOP.SET_PRINT_MODE('PRINT_NOCOLLATE', 1)
        this.LODOP.ADD_PRINT_TEXT(37, 45, 63, 20, '数量：')
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(
          63,
          46,
          134,
          20,
          this.dataForm.productQty + ' ' + this.dataForm.unit
        )
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(37, 92, 63, 20, 'SN号：')
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(69, 93, 134, 20, this.dataForm.outBatchNo)
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(23, 140, 77, 20, '零件号：')
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_TEXT(57, 141, 182, 22, this.dataForm.partNo)
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'Alignment', 2)
        this.LODOP.SET_PRINT_STYLEA(0, 'Bold', 1)
        this.LODOP.SET_PRINT_STYLEA(0, 'Angle', 270)
        this.LODOP.ADD_PRINT_BARCODE(45, 215, 149, 181, 'QRCode', qrStr)
        this.LODOP.SET_PRINT_STYLEA(0, 'FontSize', 10)
        this.LODOP.SET_PRINT_STYLEA(0, 'QRCodeVersion', 7)
        this.LODOP.SET_PRINT_STYLEA(0, 'QRCodeErrorLevel', 'L')
        // this.LODOP.PREVIEW()
        this.LODOP.PRINT()
      }
    }
  }
}
</script>
<style scoped></style>
